import { createStore } from 'vuex'
import { v4 as uuidv4 } from "uuid"
import { instance } from "./axios"


export default createStore({
  state: {
    counter: 1,
    projects: {},
    user: null,
    errors: []
  },

  mutations: {
    addError(state, message) {
      let error = {'id': uuidv4(), 'message': message}
      state.errors.push(error)
    },
    removeError(state, error) {
      state.errors = state.errors.filter(err => err.id != error.id )
    },
    clearErrors(state) {
      state.errors = []
    },
    increment(state, amount) {
      state.counter += amount
    },
    decrement(state, amount) {
      state.counter -= amount
    },
    setProjects(state, projects) {
      state.projects = projects
    },
    setUser(state, user) {
      state.user = user
    }
  },
  getters: {
    isAuthenticated: state => !!state.user
  },
  actions: {
    async login({commit}, auth) {
      try {
        const response = await instance.get('/users/')
        let user_object = response.data.results[0]
        user_object.auth = auth
        commit('setUser', user_object)
      } catch(err) {
        commit('setUser', null)
        commit('addError', JSON.stringify(err.response.data))
      }
    },
    async loadProjects({commit}) {
      // Send response
      try {
        const response = await instance.get('/projects/')
        commit('setProjects', response.data.results)
      } catch(err) {
        commit('addError', JSON.stringify(err.response.data))
      }
    },
    async createProject({dispatch, commit}, payload) {
      try {
        await instance.post('/projects/', payload)
        dispatch('loadProjects')
      } catch(err) {
        commit('addError', JSON.stringify(err.response.data))
      }
    },
    async deleteProject({commit, dispatch}, id) {
      // Send response
      try {
        await instance.delete(`projects/${id}/`)
        dispatch('loadProjects')
      } catch(err) {
        commit('addError', JSON.stringify(err.response.data))
      }
    }
  },
  modules: {
  }
})
